| Title: | Multiply robust estimation in causal survival analysis with treatment noncompliance |
|---|---|
| Description: | This package provides functions to calculate the multiply robust estimator of the principal survival causal effect among the always takers, compliers, and never takers. |
| Authors: | Chao Cheng <[email protected]>, Bo Liu <[email protected]>, Fan Li <[email protected]>, Fan Li <[email protected]> |
| Maintainer: | Chao Cheng <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.0 |
| Built: | 2026-05-13 10:42:01 UTC |
| Source: | https://github.com/chaochengstat/mrpstrata |
Bootstrap confidence intervals for the bias-corrected multiply robust estimator under violations of monotonicity
BootEst.MO.SA( times, propensity.model, principal.model, censor.model, failure.model, data, zeta, estimand = c("NACE", "CACE", "AACE", "DACE"), bootstrap = 50 )BootEst.MO.SA( times, propensity.model, principal.model, censor.model, failure.model, data, zeta, estimand = c("NACE", "CACE", "AACE", "DACE"), bootstrap = 50 )
times |
a vector of time when the principal survival causal effects (PSCEs) are of interest |
propensity.model |
propensity score model |
principal.model |
principal score model |
censor.model |
censoring model |
failure.model |
outcome model |
data |
dataset |
zeta |
the sensitivity parameter zeta |
estimand |
the estimands of interest |
bootstrap |
number of bootstrap replications |
The bootstrap confidence intervals
Bootstrap confidence intervals for the multiply robust estimator
BootEst.PI.SA( times, propensity.model, principal.model, censor.model, failure.model, data, xi0, xi1, eta0, eta1, estimand = c("NACE", "CACE", "AACE"), bootstrap )BootEst.PI.SA( times, propensity.model, principal.model, censor.model, failure.model, data, xi0, xi1, eta0, eta1, estimand = c("NACE", "CACE", "AACE"), bootstrap )
times |
a vector of time when the principal survival causal effects (PSCEs) are of interest |
propensity.model |
propensity score model |
principal.model |
principal score model |
censor.model |
censoring model |
failure.model |
outcome model |
data |
dataset |
xi0 |
sensitivity parameter xi_0 |
xi1 |
sensitivity parameter xi_1 |
eta0 |
sensitivity parameter eta_0 |
eta1 |
sensitivity parameter eta_1 |
estimand |
the estimands of interest |
bootstrap |
number of bootstrap replications |
The bootstrap confidence intervals
Multiply robust estimator for calculating the principal survival causal effects among always takers, compliers, and never takers
mrPStrata( times, data, Xpi_names, Xe_names, Xc_names, Xt_names, Z_name, S_name, U_name, delta_name, B = 100 )mrPStrata( times, data, Xpi_names, Xe_names, Xc_names, Xt_names, Z_name, S_name, U_name, delta_name, B = 100 )
times |
a vector of time when the principal survival causal effects (PSCEs) are of interest |
data |
the dataset |
Xpi_names |
names of the covariates for the propensity score model |
Xe_names |
names of the covariates for the principal score model |
Xc_names |
names of the covariates for the censoring model |
Xt_names |
names of the covariates for the failure outcome model |
Z_name |
name of the treatment assignment status |
S_name |
name of the true treatment receipt status |
U_name |
name of the observed failuture time |
delta_name |
name of the censoring indicator |
B |
number of the bootstrap replications (default 100) |
The PSCE estimates and their 95% confidence intervals
# example code attach(sim_data) res = mrPStrata(times=c(1,2,3,4,5,6,7,8), data = sim_data, Xpi_names = c("X1","X2","X3","X4","X5"), Xe_names = c("X1","X2","X3","X4","X5"), Xc_names = c("X1","X2","X3","X4","X5"), Xt_names = c("X1","X2","X3","X4","X5"), Z_name = "z", S_name = "s", U_name ="U", delta_name = "delta", B=50) print(res)# example code attach(sim_data) res = mrPStrata(times=c(1,2,3,4,5,6,7,8), data = sim_data, Xpi_names = c("X1","X2","X3","X4","X5"), Xe_names = c("X1","X2","X3","X4","X5"), Xc_names = c("X1","X2","X3","X4","X5"), Xt_names = c("X1","X2","X3","X4","X5"), Z_name = "z", S_name = "s", U_name ="U", delta_name = "delta", B=50) print(res)
Bias-corrected multiply robust estimator of the PSCE under violation of monotonicity
mrPStrata_MO_SA( times, data, Xpi_names, Xe_names, Xc_names, Xt_names, Z_name, S_name, U_name, delta_name, zeta = 0.01, B = 100 )mrPStrata_MO_SA( times, data, Xpi_names, Xe_names, Xc_names, Xt_names, Z_name, S_name, U_name, delta_name, zeta = 0.01, B = 100 )
times |
a vector of time when the principal survival causal effects (PSCEs) are of interest |
data |
the dataset |
Xpi_names |
names of the covariates for the propensity score model |
Xe_names |
names of the covariates for the principal score model |
Xc_names |
names of the covariates for the censoring model |
Xt_names |
names of the covariates for the outcome model |
Z_name |
name of the treatment assignment status |
S_name |
name of the true treatment receipt status |
U_name |
name of the observed failuture time |
delta_name |
name of the censoring indicator |
zeta |
sensitivity parameter zeta |
B |
number of the bootstrap replications (default 100) |
The PSCE estimates and their 95% confidence intervals
Bias-corrected multiply robust estimator of the PSCE under violation of the principal ignorability assumption
mrPStrata_PI_SA( times, data, Xpi_names, Xe_names, Xc_names, Xt_names, Z_name, S_name, U_name, delta_name, xi0 = 0, xi1 = 0, eta0 = 1, eta1 = 1, B = 100 )mrPStrata_PI_SA( times, data, Xpi_names, Xe_names, Xc_names, Xt_names, Z_name, S_name, U_name, delta_name, xi0 = 0, xi1 = 0, eta0 = 1, eta1 = 1, B = 100 )
times |
a vector of time when the principal survival causal effects (PSCEs) are of interest |
data |
the dataset |
Xpi_names |
names of the covariates for the propensity score model |
Xe_names |
names of the covariates for the principal score model |
Xc_names |
names of the covariates for the censoring model |
Xt_names |
names of the covariates for the outcome model |
Z_name |
name of the treatment assignment status |
S_name |
name of the true treatment receipt status |
U_name |
name of the observed failuture time |
delta_name |
name of the censoring indicator |
xi0 |
sensitivity parameter xi_0 |
xi1 |
sensitivity parameter xi_1 |
eta0 |
sensitivity parameter eta_0 |
eta1 |
sensitivity parameter eta_1 |
B |
number of the bootstrap replications (default 100) |
The PSCE estimates and their 95% confidence intervals
Plot of the PSCEs and their associated 95% pointwise confidence intervals
## S3 method for class 'psce' plot(res)## S3 method for class 'psce' plot(res)
res |
an output from mrPStrata |
The PSCE point estimates and 95% pointwise confidence intervals
Point estimation for the multiply robust estimator under violation of monotonicity assumption
PointEst.MO.SA( times, propensity.model, principal.model, censor.model, failure.model, data, zeta, estimand = c("NACE", "CACE", "AACE", "DACE") )PointEst.MO.SA( times, propensity.model, principal.model, censor.model, failure.model, data, zeta, estimand = c("NACE", "CACE", "AACE", "DACE") )
times |
a vector of time when the principal survival causal effects (PSCEs) are of interest |
propensity.model |
propensity score model |
principal.model |
principal score model |
censor.model |
censoring model |
failure.model |
outcome model |
data |
dataset |
zeta |
the sensitivity parameter zeta |
estimand |
the estimands of interest |
The PSCE point estimates
Point estimation for the multiply robust estimator
PointEst.PI.SA( times, propensity.model, principal.model, censor.model, failure.model, data, xi0, xi1, eta0, eta1, estimand = c("NACE", "CACE", "AACE") )PointEst.PI.SA( times, propensity.model, principal.model, censor.model, failure.model, data, xi0, xi1, eta0, eta1, estimand = c("NACE", "CACE", "AACE") )
times |
a vector of time when the principal survival causal effects (PSCEs) are of interest |
propensity.model |
propensity score model |
principal.model |
principal score model |
censor.model |
censoring model |
failure.model |
outcome model |
data |
dataset |
xi0 |
sensitivity parameter xi_0 |
xi1 |
sensitivity parameter xi_1 |
eta0 |
sensitivity parameter eta_0 |
eta1 |
sensitivity parameter eta_1 |
estimand |
the estimands of interest |
The PSCE point estimates