Package {mrPStrata}


Type: Package
Title: Multiply Robust Estimation in Causal Survival Analysis with Treatment Noncompliance
Version: 0.1.0
Description: Provides multiply robust estimators of principal survival causal effects among always-takers, compliers, and never-takers in studies with treatment noncompliance. The methods are based on Cheng et al. (2026) <doi:10.1214/25-AOAS2117>.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Encoding: UTF-8
LazyData: true
Depends: R (≥ 2.10)
Imports: dplyr, ggplot2, magrittr, progress, survival
Suggests: knitr, rmarkdown, testthat (≥ 3.0.0)
Config/testthat/edition: 3
RoxygenNote: 7.3.3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-05-06 16:44:20 UTC; chaocheng
Author: Chao Cheng [aut, cre], Bo Liu [aut], Fan Li [aut], Fan Li [aut]
Maintainer: Chao Cheng <chaoc@wustl.edu>
Repository: CRAN
Date/Publication: 2026-05-12 17:40:02 UTC

Bootstrap confidence intervals for the bias-corrected multiply robust estimator under violations of monotonicity

Description

Bootstrap confidence intervals for the bias-corrected multiply robust estimator under violations of monotonicity

Usage

BootEst.MO.SA(
  times,
  propensity.model,
  principal.model,
  censor.model,
  failure.model,
  data,
  zeta,
  estimand = c("NACE", "CACE", "AACE", "DACE"),
  bootstrap = 50
)

Arguments

times

a vector of time when the principal survival causal effects (PSCEs) are of interest

propensity.model

propensity score model

principal.model

principal score model

censor.model

censoring model

failure.model

outcome model

data

dataset

zeta

the sensitivity parameter zeta

estimand

the estimands of interest

bootstrap

number of bootstrap replications

Value

The bootstrap confidence intervals


Bootstrap confidence intervals for the multiply robust estimator

Description

Bootstrap confidence intervals for the multiply robust estimator

Usage

BootEst.PI.SA(
  times,
  propensity.model,
  principal.model,
  censor.model,
  failure.model,
  data,
  xi0,
  xi1,
  eta0,
  eta1,
  estimand = c("NACE", "CACE", "AACE"),
  bootstrap
)

Arguments

times

a vector of time when the principal survival causal effects (PSCEs) are of interest

propensity.model

propensity score model

principal.model

principal score model

censor.model

censoring model

failure.model

outcome model

data

dataset

xi0

sensitivity parameter xi_0

xi1

sensitivity parameter xi_1

eta0

sensitivity parameter eta_0

eta1

sensitivity parameter eta_1

estimand

the estimands of interest

bootstrap

number of bootstrap replications

Value

The bootstrap confidence intervals


Point estimation for the multiply robust estimator under violation of monotonicity assumption

Description

Point estimation for the multiply robust estimator under violation of monotonicity assumption

Usage

PointEst.MO.SA(
  times,
  propensity.model,
  principal.model,
  censor.model,
  failure.model,
  data,
  zeta,
  estimand = c("NACE", "CACE", "AACE", "DACE")
)

Arguments

times

a vector of time when the principal survival causal effects (PSCEs) are of interest

propensity.model

propensity score model

principal.model

principal score model

censor.model

censoring model

failure.model

outcome model

data

dataset

zeta

the sensitivity parameter zeta

estimand

the estimands of interest

Value

The PSCE point estimates


Point estimation for the multiply robust estimator

Description

Point estimation for the multiply robust estimator

Usage

PointEst.PI.SA(
  times,
  propensity.model,
  principal.model,
  censor.model,
  failure.model,
  data,
  xi0,
  xi1,
  eta0,
  eta1,
  estimand = c("NACE", "CACE", "AACE")
)

Arguments

times

a vector of time when the principal survival causal effects (PSCEs) are of interest

propensity.model

propensity score model

principal.model

principal score model

censor.model

censoring model

failure.model

outcome model

data

dataset

xi0

sensitivity parameter xi_0

xi1

sensitivity parameter xi_1

eta0

sensitivity parameter eta_0

eta1

sensitivity parameter eta_1

estimand

the estimands of interest

Value

The PSCE point estimates


Multiply robust estimator for calculating the principal survival causal effects among always takers, compliers, and never takers

Description

Multiply robust estimator for calculating the principal survival causal effects among always takers, compliers, and never takers

Usage

mrPStrata(
  times,
  data,
  Xpi_names,
  Xe_names,
  Xc_names,
  Xt_names,
  Z_name,
  S_name,
  U_name,
  delta_name,
  B = 100
)

Arguments

times

a vector of time when the principal survival causal effects (PSCEs) are of interest

data

the dataset

Xpi_names

names of the covariates for the propensity score model

Xe_names

names of the covariates for the principal score model

Xc_names

names of the covariates for the censoring model

Xt_names

names of the covariates for the failure outcome model

Z_name

name of the treatment assignment status

S_name

name of the true treatment receipt status

U_name

name of the observed failuture time

delta_name

name of the censoring indicator

B

number of the bootstrap replications (default 100)

Value

The PSCE estimates and their 95% confidence intervals

Examples

# example code
attach(sim_data)
sim_data = sim_data[1:1000,]
res = mrPStrata(times=c(1,2,3,4,5,6,7,8),
                data = sim_data,
                Xpi_names = c("X1","X2","X3","X4","X5"),
                Xe_names = c("X1","X2","X3","X4","X5"),
                Xc_names = c("X1","X2","X3","X4","X5"),
                Xt_names = c("X1","X2","X3","X4","X5"),
                Z_name = "z",
                S_name = "s",
                U_name ="U",
                delta_name = "delta",
                B=3)
res

Bias-corrected multiply robust estimator of the PSCE under violation of monotonicity

Description

Bias-corrected multiply robust estimator of the PSCE under violation of monotonicity

Usage

mrPStrata_MO_SA(
  times,
  data,
  Xpi_names,
  Xe_names,
  Xc_names,
  Xt_names,
  Z_name,
  S_name,
  U_name,
  delta_name,
  zeta = 0.01,
  B = 100
)

Arguments

times

a vector of time when the principal survival causal effects (PSCEs) are of interest

data

the dataset

Xpi_names

names of the covariates for the propensity score model

Xe_names

names of the covariates for the principal score model

Xc_names

names of the covariates for the censoring model

Xt_names

names of the covariates for the outcome model

Z_name

name of the treatment assignment status

S_name

name of the true treatment receipt status

U_name

name of the observed failuture time

delta_name

name of the censoring indicator

zeta

sensitivity parameter zeta

B

number of the bootstrap replications (default 100)

Value

The PSCE estimates and their 95% confidence intervals


Bias-corrected multiply robust estimator of the PSCE under violation of the principal ignorability assumption

Description

Bias-corrected multiply robust estimator of the PSCE under violation of the principal ignorability assumption

Usage

mrPStrata_PI_SA(
  times,
  data,
  Xpi_names,
  Xe_names,
  Xc_names,
  Xt_names,
  Z_name,
  S_name,
  U_name,
  delta_name,
  xi0 = 0,
  xi1 = 0,
  eta0 = 1,
  eta1 = 1,
  B = 100
)

Arguments

times

a vector of time when the principal survival causal effects (PSCEs) are of interest

data

the dataset

Xpi_names

names of the covariates for the propensity score model

Xe_names

names of the covariates for the principal score model

Xc_names

names of the covariates for the censoring model

Xt_names

names of the covariates for the outcome model

Z_name

name of the treatment assignment status

S_name

name of the true treatment receipt status

U_name

name of the observed failuture time

delta_name

name of the censoring indicator

xi0

sensitivity parameter xi_0

xi1

sensitivity parameter xi_1

eta0

sensitivity parameter eta_0

eta1

sensitivity parameter eta_1

B

number of the bootstrap replications (default 100)

Value

The PSCE estimates and their 95% confidence intervals


Plot of the PSCEs and their associated 95% pointwise confidence intervals

Description

Plot of the PSCEs and their associated 95% pointwise confidence intervals

Usage

## S3 method for class 'psce'
plot(res)

Arguments

res

an output from mrPStrata

Value

The PSCE point estimates and 95% pointwise confidence intervals


Simulated survival dataset

Description

A simulated dataset used to illustrate the functions in this package.

Usage

sim_data

Format

A data frame with rows corresponding to individuals and the following variables:

U

Observed event time.

delta

Event indicator, where 1 indicates that the event was observed and 0 indicates censoring.

z

Treatment assignment status.

s

Treatment receipt status.

X1

Baseline covariate 1.

X2

Baseline covariate 2.

X3

Baseline covariate 3.

X4

Baseline covariate 4.

X5

Baseline covariate 5.

Details

The dataset contains simulated observations with an observed event time, event indicator, treatment assignment status, treatment receipt status, and five baseline covariates.

Simulated by the package authors for illustration purposes.

Examples

data(sim_data)
head(sim_data)